const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_room_detail
} = require('../../utils/api.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    code: null,
    isLoading: true,
    roomData: null,
    roomList: null,
    selectIndex: 0
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const {
      code
    } = options;
    if (options && code) {
      this.data.code = code;
      this.loadData();
    }
  },

  loadData: function () {
    let params = {};
    params.url = api_room_detail;
    params.data = {
      code: this.data.code
    };
    net.req(params, true).then((data) => {
      if (Array.isArray(data.rentHouseRoomData)) {
        const roomList = data.rentHouseRoomData.filter(item => item.status == '1')
        this.setData({
          isLoading: false,
          roomData: data,
          roomList: roomList
        });
      } else {
        util.showToast("该房间无可选租期,请你选择其它房间");
        wx.navigateBack()
      }
    }, (e) => {
      this.setData({
        isLoading: false,
        roomData: null
      });
      util.showToast(e.msg);
    });

  },

  tapRoomAction(e) {
    const {
      currentIndex,
      currentItem
    } = e.currentTarget.dataset
    if (currentItem.status == "2") {
      util.showToast("您选择的租期已租满,请选择其它租期")
    } else {
      this.setData({
        selectIndex: currentIndex
      })
    }
  },
  tapNextAction() {
    const {
      roomList,
      roomData,
      code,
      selectIndex
    } = this.data
    const {
      countryId,
      cityId,
      roomId,
      houseType
    } = roomData
    const {
      price,
      rentTime,
      rentTimeUnit,
      status,
      id
    } = roomList[selectIndex]
    if (parseInt(status) == "1") {
      const data = {
        countryId: countryId,
        cityId: cityId,
        houseId: roomId,
        id: id,
        houseType: houseType,
        houseCode: code,
        roomPrice: price,
        rentTime: rentTime,
        rentTimeUnit: rentTimeUnit
      }
      wx.navigateTo({
        url: '/pages/applyReserve/applyReserve?data=' + JSON.stringify(data)
      });
    } else {
      util.showToast("您选择的租期已租满,请选择其它租期")
    }
  },

})