// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_get_cities
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    citySelectObj: null,
    countrySelectObj: null,
    baseData: null,
    cityData: [],
    hotCity: [],
    scrollTop: 0,
    alphabetData: null,
    toView: ''
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let {
      citySelectObj,
      countrySelectObj
    } = this.data;
    citySelectObj = util.getStorageSync('citySelectObj');
    countrySelectObj = util.getStorageSync('countrySelectObj');
    this.setData({
      citySelectObj,
      countrySelectObj
    }, () => {
      this.loadData();
    });
  },

  loadData: function () {
    let params = {};
    params.data = {
      range: 'D',
      hotCity: "1",
      level: '[1,3]'
    }
    params.url = api_get_cities;
    net.req(params, true).then((data) => {
      this.setData({
        isLoading: false
      });
      this.adapter(data);
    }, (e) => {
      this.setData({
        isLoading: false,
        dataArr: []
      });
    });
  },
  // 选择国家
  selectCountry(e) {
    const {
      countryItem
    } = e.currentTarget.dataset;
    this.refreshData(countryItem);
  },

  refreshData(item) {
    let {
      dataArr
    } = this.data;
    if (item) {
      dataArr.forEach(element => {
        if (element.id === item.id) {
          let alphabetData = [];
          if (element.son) {
            element.son.forEach(element => {
              alphabetData.push(element.tip);
            });
            alphabetData = [...new Set(alphabetData)];
            if (element.hot && element.hot.citys && element.hot.citys.length) {
              alphabetData.unshift(element.hot.tip);
            }
          }

          this.setData({
            cityData: element.son || [],
            countrySelectObj: item,
            hotCity: element.hot || [],
            alphabetData: alphabetData
          }, () => {
            this.setData({
              scrollTop: 0
            })
          })
        }
      });
    } else {
      const data = dataArr[0];
      let alphabetData = [];
      if (data.son) {
        data.son.forEach(element => {
          alphabetData.push(element.tip);
        });
        alphabetData = [...new Set(alphabetData)];
        if (data.hot && data.hot.citys && data.hot.citys.length) {
          alphabetData.unshift(data.hot.tip);
        }
      }

      this.setData({
        countrySelectObj: data,
        cityData: data.son || [],
        hotCity: data.hot || [],
        alphabetData: alphabetData
      })
    }
  },
  // 选择城市
  selectCity(e) {
    const {
      cityItem
    } = e.currentTarget.dataset;
    wx.setStorageSync('citySelectObj', cityItem);
    wx.setStorageSync('countrySelectObj', this.data.countrySelectObj);
    wx.reLaunch({
      url: '/pages/index/index'
    });
  },

  adapter: function (arr) {
    if (!arr || !Array.isArray(arr) || arr.length === 0) {
      this.setData({
        dataArr: []
      });
      return false;
    }
    this.setData({
      dataArr: arr,
      baseData: arr
    });
    this.refreshData(this.data.countrySelectObj);
  },

  tapAlphabetAction(e) {
    let {
      currentItem
    } = e.currentTarget.dataset;
    if (currentItem == this.data.hotCity.tip) { // 因为id不能为中文
      currentItem = "RMC";
    }
    this.setData({
      toView: currentItem
    })
  }
})