// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_collect_list,
  api_collect_del
} = require('../../utils/api.js');

Page({
  data: {
    isLoading: true,
    listParams: {
      cate: 1, // 房源
      // contentType: 1, // 公寓 1 整租/合租 2
      page: 1,
      pageSize: 8
    },
    houseList: null,
    hasMoreData: true
  },

  onShow: function (options) {
    this.data.listParams.page = 1
    this.loadCollectData();
  },

  loadCollectData: function () {
    // this.setData({ isLoading: true })
    const { listParams, houseList } = this.data
    net.req({
      url: api_collect_list,
      data: { ...listParams }
    }).then((result) => {
      this.setData({
        houseList: listParams.page > 1 ? houseList.concat(result.list) : result.list || [],
        hasMoreData: result.totalCount > listParams.page * listParams.pageSize
      });
    }).catch((err) => {
      // 获取下一页错误时，页面重置到上一页，等待下次触底事件
      this.data.listParams.page = listParams.page - 1 || 1
    }).finally(() => {
      this.setData({ isLoading: false })
    })
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.hasMoreData) {
      this.data.listParams.page += 1;
      this.loadCollectData();
    }
  },

  // tab切换
  tapTabAction: function (e) {
    const { type } = e.target.dataset
    this.setData({
      'listParams.page': 1,
      'listParams.contentType': type
    })
    this.loadCollectData();
  },

  // item点击事件
  tabItemAction: function (e) {
    const { item } = e.currentTarget.dataset
    if (item.dataType == 1) {
      wx.navigateTo({
        url: `/pages/houseDetail/houseDetail?code=${item.code}`
      })
    } else {
      wx.navigateTo({
        url: `/pages/roomDetail/roomDetail?code=${item.code}`
      })
    }
  },

  tapLongpressAction: function (e) {
    const { index } = e.currentTarget.dataset;
    util.showModal({
      title: '提示',
      content: '确定删除该收藏？',
      confirmText: '确定',
      success: res => {
        if (res.confirm) {
          this.cancelCollect(index);
        }
      }
    });
  },

  cancelCollect: function (index) {
    const houseList = this.data.houseList
    net.req({
      url: api_collect_del,
      data: {
        cate: 1,
        hid: houseList[index].id
      }
    }).then((data) => {
      houseList.splice(index, 1)
      this.setData({
        houseList
      })
    }).catch(() => {})
  }
})