// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
import Poster from '../../utils/poster.js'
const {
  api_house_detail,
  api_collect_add,
  api_house_room_list,
  api_collect_del,
  api_get_QR,
  api_get_sale_info
} = require('../../utils/api.js');


const app = getApp();
Page({

  /**
   * 页面的初始数据
   */
  data: {
    code: null,
    buildingId: null,
    isLoading: true,
    bannerData: null,
    bannerImgsObj: null,
    roomData: null,
    roomList: [],
    selectRoomIndex: null, // 选择的房间类型
    data: null,
    current: 1,
    showCurrent: 0,
    currentSelectType: null,
    isCollect: 0,
    markers: null,
    userInfo: null,

    showHomeBtn: false,
    isIPX: app.globalData.isIPX,
    posterArr: null,
    template: null,
    postImgSrc: null,
    isShowQRPoster: null,
    isShowCanvas: false,
    isShowPostMask: false,
    extendObj: null,
    shareQRImgSrc: null,

    poster: null,
    hidden: true,

    bannerTypeArr: [],

    isShare: false,
    shareData: {}

  },

  /**
   * 生命周期函数--监听页面加载 43831
   */
  onLoad: function (options) {
    const {
      scene,
      code,
      id,
      shareUid
    } = options;
    if (options && scene) {
      const parmasArr = scene.split('U'); // 通过U区分房源id跟用户userCode
      if (Array.isArray(parmasArr)) {
        this.data.code = parmasArr[0]
        this.getHouseDetail();
        if (parmasArr[1] && parmasArr[1].length) {
          const userCode = "U" + parmasArr[1]; // 拼接用户userCode
          util.setStorageSync('shareUid', userCode);
          this.setData({
            isShare: true
          })
          this.getSaleInfo(userCode);
        }
      } else {
        util.showToast("房源正在维护中,请您稍后再试", null, true);
        setTimeout(function () {
          wx.reLaunch({
            url: '/pages/index/index'
          });
        }, 800);
      }
    } else if (options && (code || id)) {
      this.data.code = code || id;
      this.getHouseDetail();
      if (shareUid && shareUid.length) { // 分享用户id
        util.setStorageSync('shareUid', shareUid);
        this.setData({
          isShare: true
        })
        this.getSaleInfo(shareUid);
      }
    }

    const pages = getCurrentPages();
    if (pages.length == 1) {
      this.setData({
        showHomeBtn: true
      })
    }
    this.getUserInfo();

  },

  getSaleInfo: function (userCode) {
    let params = {};
    params.url = api_get_sale_info;
    params.data = {
      userCode: userCode
    };
    net.req(params, true).then((data) => {
      this.setData({
        shareData: data
      })
    }, (e) => {});
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const {
      share
    } = this.data.data;

    let path = '/pages/houseDetail/houseDetail?code=' + this.data.code;
    const userInfo = util.getStorageSync('userInfo');
    if (userInfo && userInfo.userCode && userInfo.userCode.length) { // 分享用户id
      path = path + '&shareUid=' + userInfo.userCode;
    }

    return {
      title: "hooli找房 | " + this.data.data.cityName,
      path: path,
      imageUrl: share.shareImgUrl,
      desc: share.shareContent
    }
  },

  loginCallback: function () {
    this.getUserInfo();
  },

  getUserInfo: function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo: userInfo
      })
    }
  },

  getHouseDetail: function () {
    let params = {};
    params.url = api_house_detail;
    params.data = {
      code: this.data.code
    };
    net.req(params, true).then((data) => {
      this.dealWithData(data);
      this.getBarcode();
      this.data.buildingId = data.buildingId
      this.getRoomListData(data.id)
    }, (e) => {
      this.setData({
        isLoading: false,
        data: null
      });

      util.showToast(e.msg, null, true);

      setTimeout(() => {
        const pages = getCurrentPages();
        if (pages.length == 1) {
          this.goHomeAction();
        } else {
          wx.navigateBack();
        }
      }, 800);
    });

  },

  dealWithData: function (data) {
    let {
      photos,
      marketTags,
      name,
      moneyUnit,
      price,
      rentTimeUnit,
      priceSuffix,
      share
    } = data;

    let extendObj = {
      img: share.shareImgUrl || "https://static.hoolihome.com/weapp/hoolihome/big_16_9.png",
      name,
      moneyUnit,
      price,
      rentTimeUnit,
      priceSuffix,
      marketTags
    }

    if (this.data.userInfo && this.data.userInfo.avatar && this.data.userInfo.avatar.length) {
      extendObj.avatar = this.data.userInfo.avatar
    }

    if (photos && Array.isArray(photos) && photos.length) {
      // fileImg （type==1） houseImg(type ==7)  video(type ==2)   vr(type==9)
      const bannerTypeArr = new Array()
      const bannerImgsObj = {}
      for (let i = 0, n = photos.length; i < n; i++) {
        const ele = photos[i];
        if (bannerImgsObj[ele.type]) {
          const obj = bannerImgsObj[ele.type]
          obj.imgs.push(ele)
          bannerImgsObj[ele.type] = obj
        } else {
          const obj = {
            text: '',
            type: ele.type,
            current: i
          }
          switch (parseInt(ele.type)) {
            case 1:
              obj.text = '图片'
              break;
            case 7:
              obj.text = '户型'
              break;
            case 2:
              obj.text = '视频'
              break;
            case 9:
              obj.text = 'VR'
              break;
            default:
              break;
          }

          bannerTypeArr.push(obj)
          obj.imgs = [ele]
          bannerImgsObj[ele.type] = obj
        }
      }

      this.setData({
        bannerData: photos,
        bannerTypeArr: bannerTypeArr,
        bannerImgsObj: bannerImgsObj,
        currentSelectType: photos[0].type,
      });
    }
    this.setData({
      data: data,
      extendObj: extendObj,
      isCollect: data.collection,
      markers: [{
        iconPath: '../../imgs/marker.png',
        id: 0,
        latitude: data.locationInfo.lat,
        longitude: data.locationInfo.lng,
        width: 28,
        height: 37
      }]
    });
  },

  getRoomListData(type) {
    let params = {};
    params.url = api_house_room_list;
    params.data = {
      buildingId: this.data.buildingId
    };
    if (type) {
      params.data.type = type
    }
    net.req(params, true).then((data) => {
      if (data && Array.isArray(data)) {
        this.setData({
          roomData: data,
          roomList: data[0] ? data[0].list : [],
          selectRoomIndex: 0
        }, function () {
          setTimeout(() => {
            this.setData({
              isLoading: false
            })
          }, 300)
        })
      }
    }, (e) => {
      util.showToast(e)
    });
  },

  // 切换房间类型数据
  tapHouseTypeAction(e) {
    const {
      currentIndex
    } = e.currentTarget.dataset
    const {
      roomData
    } = this.data
    this.setData({
      roomList: roomData[currentIndex].list,
      selectRoomIndex: currentIndex
    })
  },


  tapBannerAction: function (e) {
    const {
      bannerItem
    } = e.currentTarget.dataset
    const {
      bannerImgsObj
    } = this.data

    // fileImg （type==1） houseImg(type ==7)  video(type ==2)   vr(type==9)
    switch (parseInt(bannerItem.type)) {
      case 1: {
        const imgArr = bannerImgsObj[1].imgs
        this.lookBigImage(bannerItem.imageUrl, imgArr)
      }
      break;
    case 7: {
      const imgArr = bannerImgsObj[7].imgs
      this.lookBigImage(bannerItem.imageUrl, imgArr)
    }
    break;
    case 2: {
      const imgArr = bannerImgsObj[2].imgs
      wx.navigateTo({
        url: '/pages/houseVideoVR/houseVideoVR?data=' + encodeURIComponent(JSON.stringify(imgArr)) + "&type=video"
      });
    }
    break;
    case 9: {
      const imgArr = bannerImgsObj[9].imgs
      wx.navigateTo({
        url: '/pages/houseVideoVR/houseVideoVR?data=' + encodeURIComponent(JSON.stringify(imgArr)) + "&type=VR"
      });
    }
    break;
    default:
      break;
    }
  },

  tapChangeImgType(e) {
    const {
      currentItem
    } = e.currentTarget.dataset
    const {
      type,
      current
    } = currentItem
    type != this.data.currentSelectType && this.setData({
      showCurrent: current,
      current: current + 1,
      currentSelectType: type
    })
  },


  lookBigImage(imageUrl, imgArr) {
    let imgs = new Array()
    for (let i = 0, n = imgArr.length; i < n; i++) {
      imgs.push(imgArr[i].imageUrl);
    }
    wx.previewImage({
      current: imageUrl, // 当前显示图片的http链接
      urls: imgs // 需要预览的图片http链接列表
    })
  },

  // 房型介绍
  tapRoomType() {
    wx.navigateTo({
      url: '/pages/roomTypeIntro/roomTypeIntro'
    });
  },

  // 查看更多服务与设施
  tapMoreTags() {
    const {
      facilitiesTags
    } = this.data.data
    wx.navigateTo({
      url: '/pages/supportFacilities/supportFacilities?data=' + encodeURIComponent(JSON.stringify(facilitiesTags.tagList))
    });
  },

  bindchange: function (e) {
    const {
      current
    } = e.detail;
    const {
      bannerData,
      currentSelectType
    } = this.data
    const data = bannerData[current]
    if (data.type == currentSelectType) {
      this.setData({
        current: current + 1
      })
    } else {
      this.setData({
        current: current + 1,
        currentSelectType: data.type
      })
    }
  },


  lookAllHouseAction: function () {
    wx.navigateTo({
      url: '/pages/allHouse/allHouse?houseId=' + this.data.data.buildingId + "&roomIndex=" + this.data.selectRoomIndex + "&typeList=" + JSON.stringify(this.data.roomData.typeList)
    });
  },



  collectAction: function () {
    if (this.data.userInfo) {
      const isCollect = this.data.isCollect;
      let params = {};
      params.url = isCollect == 1 ? api_collect_del : api_collect_add;
      params.data = {
        cate: 1,
        hid: this.data.data.buildingId
      };
      net.req(params, true).then((data) => {
        this.setData({
          isCollect: !isCollect
        });
      }, (e) => {

      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },

  tapMapAction: function () {
    const data = this.data.data;
    if (data.locationInfo.lat && data.locationInfo.lat.length && data.locationInfo.lng && data.locationInfo.lng.length) {
      const webUrl = data.introduce.detailUrl + "&bigMap=map"
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${encodeURIComponent(webUrl)}&name=位置及周边`
      });
    }
  },


  copyHouseNumAction: function () {
    const {
      code
    } = this.data.data;
    wx.setClipboardData({
      data: code,
      success(res) {}
    })
  },

  lookProtocolAction: function () {
    const data = this.data.data;
    if (data.protocol && data.protocol.length) {
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${encodeURIComponent(data.protocol)}`
      });
    }
  },

  tapLookMoreAction: function (e) {
    const {
      detailUrl
    } = e.currentTarget.dataset
    wx.navigateTo({
      url: `/pages/webView/webView?webUrl=${encodeURIComponent(detailUrl)}&name=公寓设施`
    });
  },

  shareAction: function () {
    if (this.data.postImgSrc) {
      this.setData({
        showMask: true
      });
    } else {
      util.showToast("分享优化中,请使用微信小程序自带分享...", null, true);
    }
  },

  getBarcode: function () {
    let {
      userInfo,
      code,
      data
    } = this.data;
    let shareToken = code;
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      shareToken += userInfo.userCode
    }

    shareToken = shareToken.length > 32 ? shareToken.substring(0, 31) : shareToken; // 做容错判断,超过32位
    let params = {};
    params.url = api_get_QR;
    params.data = {
      project: data.share.project,
      scene: shareToken,
      page: data.share.smallProjectPath,
      width: 150,
      contentType: data.share.contentType
    };
    net.req(params).then((res) => {
      let postImgSrc = res.host + res.url;
      this.setData({
        postImgSrc: postImgSrc,
        isShowQRPoster: true
      });
    });
  },

  maskHide: function () {
    this.setData({
      showMask: false
    });
  },

  postMaskHide: function () {
    this.setData({
      isShowPostMask: false
    });
  },


  goHomeAction: function () {
    wx.reLaunch({
      url: '/pages/index/index'
    });
  },


  posterCallack: function (arr) {
    if (!arr) return;
    arr.forEach((v, i, a) => {
      let {
        id,
        dataset
      } = v;
      if (id.indexOf('img') !== -1) {
        wx.getImageInfo({
          src: dataset.what,
          success: (res) => {
            v.dataset.uri = res.path;
          }
        });
      }
    });
    this.data.posterArr = arr

  },
  onImgOK: function (e) {
    const canvasSrc = e.detail.path;
    wx.hideLoading();

    this.setData({
      isShowCanvas: false
    }, () => {
      this.setData({
        shareQRImgSrc: canvasSrc
      })

      wx.previewImage({
        current: canvasSrc, // 当前显示图片的http链接
        urls: [canvasSrc] // 需要预览的图片http链接列表
      })
    });
  },

  handleGeneratePoster: function () {
    const _this = this;
    if (this.data.shareQRImgSrc) {
      wx.previewImage({
        current: this.data.shareQRImgSrc, // 当前显示图片的http链接
        urls: [this.data.shareQRImgSrc] // 需要预览的图片http链接列表
      })
      return;
    }

    _this.setData({
      showMask: false,
      isShowCanvas: true,
      isShowQRPoster: false
    }, () => {
      let palette = new Poster().palette(this.data.posterArr);
      this.setData({
        template: palette
      });
      wx.showLoading({
        title: '生成海报中...'
      });
    });


  },
  saveImgAction: function () {
    const _this = this;
    wx.saveImageToPhotosAlbum({
      filePath: this.data.shareQRImgSrc,
      success(res) {
        wx.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        });
        _this.setData({
          isShowPostMask: false
        })
      },
      fail() {
        wx.showModal({
          title: '授权失败',
          content: '是否打开小程序设置界面，完成对该小程序授权状态',
          success: function (res) {
            if (res.confirm) {
              wx.openSetting({
                success(res) {}
              })
            }
          }
        })
      }
    })
  },


  hiddenVideoToast: function () {
    this.setData({
      videoSrc: null,
      poster: null,
      hidden: true
    }, () => {})
  },


  tapTelAction: function () {
    const tel = this.data.shareData.mobile || '';
    let systemInfo = util.getStorageSync('systemInfo');
    if (!systemInfo) {
      systemInfo = wx.getSystemInfoSync();
      if (systemInfo) {
        wx.setStorageSync('systemInfo', systemInfo);
      }
    }
    let {
      system
    } = systemInfo;
    if (system.toLowerCase().indexOf('ios') !== -1) {
      wx.makePhoneCall({
        phoneNumber: tel
      });
    } else {
      wx.showActionSheet({
        itemList: [tel],
        success(res) {
          if (res.tapIndex === 0) {
            wx.makePhoneCall({
              phoneNumber: tel
            });
          }
        }
      })
    }
  },

  selectRoomAction: function () {
    const query = wx.createSelectorQuery();
    query.selectAll('.canvas-part').boundingClientRect(function (res) {
      if (Array.isArray(res)) {
        wx.pageScrollTo({
          scrollTop: res[0].height + res[1].height + 50
        })
      }
    }).exec();
  }
})