// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const {
  getStorageSync,
  compareVersion,
  urlParse,
  jsonClone,
  debounce
} = require('../../utils/util.js');
const {
  api_filter_house,
  api_filter_school,
  api_filter_sort,
  api_house_list
} = require('../../utils/api.js');

let cachedFilter = {}

Page({

  /**
   * 页面的初始数据
   */
  data: {
    initFilterData: false,
    bodyFixed: false,
    isLoading: true,
    hasMoreData: true,
    fromIndex: true,
    // navbar
    pageMarginTop: 0,
    searchInPage: false,
    searchName: '',
    listQuery: {
      page: 1,
      pageSize: 10
    },
    listParams: {
      contentType: '1' // 1公寓 2整租/合租
    },
    minPrice: '',
    maxPrice: '',
    resultType: '', // 0空 1公寓 2社会房源 3公寓+社会房源
    tatolCount: 0,
    houseList: [],
    pageTitle: '', // 学校 筛选
    showBedBath: false, // 显示卧室、卫浴
    sortSheetVisiable: false, // 排序
    schoolOptions: null,
    filterOptions: null,
    sortOptions: null,
    listAD: null
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let {
      version
    } = getStorageSync('systemInfo');

    if (!version) {
      const systemInfo = wx.getSystemInfoSync();
      wx.setStorageSync('systemInfo', systemInfo);
      version = systemInfo.version
    }

    let searchInPage = false;
    // version < 7.0.0 不支持页面自定义navbar
    if (compareVersion(version, '7.0.0') < 0) {
      searchInPage = true;
    }

    const listParams = {
      contentType: '1'
    }
    let searchName = ''
    if (options.form === 'index') {
      listParams.contentType = options.contentType
      const citySelectObj = getStorageSync('citySelectObj');
      searchName = citySelectObj.schoolName && citySelectObj.schoolName.length ? citySelectObj.schoolName : citySelectObj.cityName

    } else if (options.form === 'search') {
      const searchValue = JSON.parse(decodeURIComponent(options.searchValue))
      // 1：城市、2：学校、3：房源-楼、5社会房源
      listParams.cityId = searchValue.cityId || ''
      switch (searchValue.type) {
        case 1:
          listParams.schoolId = ''
          searchName = searchValue.cityName
          break;
        case 2:
          listParams.schoolId = searchValue.id
          searchName = searchValue.name
          break;
      }
    }

    this.setData({
      fromIndex: options.form === 'index',
      searchInPage,
      listParams,
      searchName
    });
    this.loadHouseList()

    this.debounceListCount = debounce(this.getListCount, 500)
  },

  onPullDownRefresh: function () {
    this.data.listQuery.page = 1;
    this.loadHouseList();
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.hasMoreData) {
      this.data.listQuery.page += 1;
      this.loadHouseList();
    }
  },

  /**
   * e.detail[0] navbarHeight
   * e.detail[1] contentHeight
   */
  navbarLoad: function (e) {
    this.setData({
      pageMarginTop: e.detail[0]
    });
  },
  // 关闭筛选 / 退出
  tapLeftAction: function () {
    const {
      pageTitle,
      bodyFixed
    } = this.data
    if (pageTitle) {
      // 关闭筛选则条件重置
      if (pageTitle === '筛选') {
        // 是否显示卧室卫浴
        let hasBedAndBath = false
        cachedFilter.options.roomType.values.filter(item => item.checked).some(item => {
          if (item.hasBedAndBath) {
            hasBedAndBath = !hasBedAndBath
          }
          return item.hasBedAndBath
        })
        this.setData({
          showBedBath: hasBedAndBath
        })
      }
      this.setData({
        pageTitle: '',
        searchName: cachedFilter.searchName,
        tatolCount: cachedFilter.tatolCount,
        listParams: jsonClone(cachedFilter.listParams),
        [pageTitle === '学校' ? 'schoolOptions' : 'filterOptions']: jsonClone(cachedFilter.options),
        bodyFixed: !bodyFixed
      })
      cachedFilter.listParams = null
      cachedFilter.options = null
      cachedFilter = {}
    } else {
      wx.navigateBack()
    }
  },

  tapSearchAction: function () {
    wx.navigateTo({
      url: `/pages/search/search`
    });
  },

  updateDataCallback: function (item) {
    const listParams = {
      contentType: '1'
    }
    let searchName = ''
    listParams.cityId = item.cityId || ''
    // 1：城市、2：学校、3：房源-楼、5社会房源
    switch (item.type) {
      case 1:
        listParams.schoolId = ''
        searchName = item.cityName
        break;
      case 2:
        listParams.schoolId = item.id
        searchName = item.name
        break;
    }
    this.setData({
      fromIndex: false,
      listParams,
      searchName
    })
    this.loadHouseList()
    // 切换城市或者学校，相关的搜索条件也需要刷新
    this.loadSchoolFilter()
    this.loadMoreFilter()
  },

  loadHouseList: function () {
    // this.setData({ isLoading: true })
    const {
      listQuery,
      listParams,
      houseList
    } = this.data
    // console.log(listParams);

    net.req({
      url: api_house_list,
      data: {
        ...listQuery,
        ...listParams
      }
    }).then((result) => {
      this.setData({
        // 两种数据都存在时，显示分类，只有一种时隐藏分类，类型切换到有数据的类型
        resultType: result.contentType,
        'listParams.contentType': result.contentType != 3 ? result.contentType : listParams.contentType,
        tatolCount: result.totalCount,
        houseList: listQuery.page > 1 ? houseList.concat(result.list) : result.list || [],
        hasMoreData: result.totalCount > listQuery.page * listQuery.pageSize,
        listAD: result.component || null
      })
      // 第一次列表加载完毕获取筛选条件
      if (!this.data.initFilterData) {
        setTimeout(() => {
          this.setData({
            initFilterData: true
          })
        }, 1)
        this.loadHouseFilters()
      }
    }).catch((err) => {
      // 获取下一页错误时，页面重置到上一页，等待下次触底事件
      this.data.listQuery.page = listQuery.page - 1 || 1
    }).finally(() => {
      if (this.data.isLoading) {
        this.setData({
          isLoading: false
        })
      }
      // 停止当前页面的下拉刷新
      wx.stopPullDownRefresh()
    })
  },

  getListCount: function () {
    const {
      listParams
    } = this.data

    net.req({
      url: api_house_list,
      data: {
        ...listParams,
        total: 1
      }
    }).then((result) => {
      this.setData({
        tatolCount: result.totalCount
      })
    }).catch((err) => {})
  },

  loadHouseFilters: function () {
    this.loadSchoolFilter()
    this.loadMoreFilter()
    this.loadSortFilter()
  },
  loadSchoolFilter: function () {
    const {
      listParams
    } = this.data
    net.req({
      url: api_filter_school
    }).then((result) => {
      const school = result[0]
      school.value = school.value.map(item => {
        item.checked = item.id == listParams.schoolId
        return item
      })
      this.setData({
        schoolOptions: school,
      })
    }).catch((err) => {})
  },
  loadMoreFilter: function () {
    const {
      listParams
    } = this.data
    net.req({
      url: api_filter_house,
      data: {
        type: listParams.contentType,
      }
    }).then((filter) => {
      if (filter.houseType) {
        filter.houseType.values = filter.houseType.values.map(item => (item.checked = false, item))
      }
      if (filter.price) {
        filter.price.values = filter.price.values.map(item => (item.checked = false, item))
      }
      // 整租/合租，默认房源类型
      if (filter.roomType) {
        filter.roomType.values = filter.roomType.values.map(item => {
          item.checked = false
          item.visiable = listParams.contentType == '2'
          return item
        })
      }
      if (filter.bedRoom) {
        filter.bedRoom.values = filter.bedRoom.values.map(item => (item.checked = false, item))
      }
      if (filter.bathRoom) {
        filter.bathRoom.values = filter.bathRoom.values.map(item => (item.checked = false, item))
      }
      if (filter.tag) {
        filter.tag.values = filter.tag.values.map(item => (item.checked = false, item))
      }
      this.setData({
        filterOptions: filter
      })
    }).catch((err) => {})
  },
  loadSortFilter: function () {
    net.req({
      url: api_filter_sort
    }).then((sort) => {
      sort.values = sort.values.map((item, index) => {
        item.checked = index === 0
        return item
      })
      this.setData({
        sortOptions: sort
      })
    }).catch((err) => {})
  },
  // tab切换
  tapTabAction: function (e) {
    const {
      type
    } = e.target.dataset
    const {
      listParams
    } = this.data
    const {
      schoolId,
      contentType
    } = listParams
    if (contentType == type) return
    // 切换时重置筛选条件，保留学校参数
    this.setData({
      isLoading: true,
      showBedBath: false,
      listParams: {
        schoolId,
        contentType: type
      },
      'listQuery.page': 1
    })
    this.loadHouseList()
    // 公寓、整租/合租 筛选条件不一样，需要切换时再去获取
    this.loadMoreFilter()
  },
  // item点击事件
  tabItemAction: function (e) {
    const {
      item
    } = e.currentTarget.dataset
    if (item.dataType == 1) {
      wx.navigateTo({
        url: `/pages/houseDetail/houseDetail?code=${item.code}`
      })
    } else {
      wx.navigateTo({
        url: `/pages/roomDetail/roomDetail?code=${item.code}`
      })
    }
  },
  // 学校 筛选 排序 切换时body固定样式
  setDataAction: function (params) {
    this.setData({
      ...params,
      bodyFixed: !this.data.bodyFixed
    })
  },
  // 学校
  tapSchoolAction: function (e) {
    this.setDataAction({
      pageTitle: '学校'
    })
    cachedFilter = {
      searchName: this.data.searchName,
      listParams: jsonClone(this.data.listParams),
      options: jsonClone(this.data.schoolOptions),
      tatolCount: this.data.tatolCount
    }
  },
  // 筛选
  tapFilterAction: function (e) {
    this.setDataAction({
      pageTitle: '筛选'
    })
    cachedFilter = {
      listParams: jsonClone(this.data.listParams),
      options: jsonClone(this.data.filterOptions),
      tatolCount: this.data.tatolCount
    }
  },
  // 显示数据，关闭筛选弹窗
  showHouseList: function () {
    if (!this.data.tatolCount) return

    this.setDataAction({
      pageTitle: '',
      'listQuery.page': 1
    })
    // 获取匹配房源
    this.loadHouseList()
  },
  // 获取匹配房源数量
  filterRefresh: function (params) {
    this.setData({
      ...params,
      'listQuery.page': 1
    })
    this.debounceListCount()
  },
  // 选择学校
  selectSchoolAction: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      schoolOptions
    } = this.data
    schoolOptions.value = schoolOptions.value.map((item, idx) => {
      item.checked = idx === index && !item.checked
      return item
    })
    const query = schoolOptions.value.filter(item => item.checked)[0]

    this.filterRefresh({
      schoolOptions,
      searchName: query ? query.name : '',
      'listParams.schoolId': query ? query.id : ''
    })
  },
  // 清空学校
  resetSchoolAction: function () {
    const {
      schoolOptions
    } = this.data
    schoolOptions.value = schoolOptions.value.map(item => (item.checked = false, item))
    // 重置listParams
    this.filterRefresh({
      schoolOptions,
      'listParams.schoolId': ''
    })
  },
  // 房源类型切换时，清空房间类型，清空卧室卫浴
  selectHouseType: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      houseType,
      roomType,
      bedRoom,
      bathRoom
    } = this.data.filterOptions

    houseType.values = houseType.values.map((item, idx) => {
      item.checked = idx === index && !item.checked
      return item
    })
    const query = houseType.values.filter(item => item.checked)[0] || {}
    // 房源类型切换，清空相关筛选
    const visiableMap = new Set(query.roomType || [])
    roomType.values = roomType.values.map(item => {
      item.checked = false
      item.visiable = visiableMap.has(item.value)
      return item
    })
    bedRoom.values = bedRoom.values.map(item => (item.checked = false, item))
    bathRoom.values = bathRoom.values.map(item => (item.checked = false, item))

    this.filterRefresh({
      showBedBath: false, //隐藏卧室卫浴
      'filterOptions.houseType': houseType,
      'filterOptions.roomType': roomType,
      'filterOptions.bedRoom': bedRoom,
      'filterOptions.bathRoom': bathRoom,
      [`listParams.${houseType.keys}`]: query.value ? JSON.stringify([query.value]) : '',
      [`listParams.${roomType.keys}`]: '',
      [`listParams.${bedRoom.keys}`]: '',
      [`listParams.${bathRoom.keys}`]: '',
    })
  },
  selectPrice: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      price
    } = this.data.filterOptions
    if (price.select === 1) {
      price.values = price.values.map((item, idx) => {
        item.checked = idx === index && !item.checked
        return item
      })
    } else {
      price.values = price.values.map((item, idx) => {
        if (idx === index) {
          item.checked = !item.checked
        }
        return item
      })
    }
    const query = price.values.filter(item => item.checked).map(item => [item.minPrice, item.maxPrice])
    this.filterRefresh({
      minPrice: '',
      maxPrice: '',
      'filterOptions.price': price,
      [`listParams.${price.keys}`]: query.length ? JSON.stringify(query) : ''
    })
  },
  bindMinPriceInput: function (e) {
    let {
      value,
      cursor
    } = e.detail
    if (cursor !== -1) {
      // 光标在中间
      const left = value.slice(0, cursor)
      // 计算光标的位置
      cursor = left.replace(/\D/g, '').length
    }
    value = value.replace(/\D/g, '')

    const {
      price
    } = this.data.filterOptions
    if (this.data.listParams[price.keys]) {
      price.values = price.values.map(item => (item.checked = false, item))
      this.setData({
        minPrice: value,
        'filterOptions.price': price,
        [`listParams.${price.keys}`]: ''
      })
    } else {
      this.setData({
        minPrice: value
      })
    }
    return {
      value,
      cursor
    }
  },
  bindMaxPriceInput: function (e) {
    let {
      value,
      cursor
    } = e.detail
    if (cursor !== -1) {
      // 光标在中间
      const left = value.slice(0, cursor)
      // 计算光标的位置
      cursor = left.replace(/\D/g, '').length
    }
    value = value.replace(/\D/g, '')

    const {
      price
    } = this.data.filterOptions
    if (this.data.listParams[price.keys]) {
      price.values = price.values.map(item => (item.checked = false, item))
      this.setData({
        maxPrice: value,
        'filterOptions.price': price,
        [`listParams.${price.keys}`]: ''
      })
    } else {
      this.setData({
        maxPrice: value
      })
    }
    return {
      value,
      cursor
    }
  },
  bindPriceBlur: function (params) {
    const {
      price
    } = this.data.filterOptions
    const {
      minPrice,
      maxPrice
    } = this.data
    // 两个都是空是传空字符串，有一个值时候传字符串数组
    const query = minPrice || maxPrice ? [
      [+minPrice || -1000, +maxPrice || -1000]
    ] : ''
    this.filterRefresh({
      [`listParams.${price.keys}`]: query && JSON.stringify(query)
    })
  },
  selectRoomType: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      listParams
    } = this.data
    const {
      roomType,
      bedRoom,
      bathRoom
    } = this.data.filterOptions

    if (roomType.select === 1) {
      roomType.values = roomType.values.map((item, idx) => {
        item.checked = idx === index && !item.checked
        return item
      })
    } else {
      roomType.values = roomType.values.map((item, idx) => {
        if (idx === index) {
          item.checked = !item.checked
        }
        return item
      })
    }
    // 是否显示卧室卫浴
    let hasBedAndBath = false
    const query = roomType.values.filter(item => item.checked).map(item => {
      if (item.hasBedAndBath) {
        hasBedAndBath = !hasBedAndBath
      }
      return item.value
    })
    if (!hasBedAndBath) {
      bedRoom.values = bedRoom.values.map(item => (item.checked = false, item))
      bathRoom.values = bathRoom.values.map(item => (item.checked = false, item))
    }

    this.filterRefresh({
      showBedBath: hasBedAndBath,
      'filterOptions.roomType': roomType,
      'filterOptions.bedRoom': bedRoom,
      'filterOptions.bathRoom': bathRoom,
      [`listParams.${roomType.keys}`]: query.length ? JSON.stringify(query) : '',
      [`listParams.${bedRoom.keys}`]: hasBedAndBath ? listParams[bedRoom.keys] || '' : '',
      [`listParams.${bathRoom.keys}`]: hasBedAndBath ? listParams[bathRoom.keys] || '' : ''
    })
  },
  selectBedRoom: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      bedRoom
    } = this.data.filterOptions
    if (bedRoom.select === 1) {
      bedRoom.values = bedRoom.values.map((item, idx) => {
        item.checked = idx === index && !item.checked
        return item
      })
    } else {
      bedRoom.values = bedRoom.values.map((item, idx) => {
        if (idx === index) {
          item.checked = !item.checked
        }
        return item
      })
    }
    const query = bedRoom.values.filter(item => item.checked).map(item => item.value)
    this.filterRefresh({
      'filterOptions.bedRoom': bedRoom,
      [`listParams.${bedRoom.keys}`]: query.length ? JSON.stringify(query) : ''
    })
  },
  selectBathRoom: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      bathRoom
    } = this.data.filterOptions
    if (bathRoom.select === 1) {
      bathRoom.values = bathRoom.values.map((item, idx) => {
        item.checked = idx === index && !item.checked
        return item
      })
    } else {
      bathRoom.values = bathRoom.values.map((item, idx) => {
        if (idx === index) {
          item.checked = !item.checked
        }
        return item
      })
    }
    const query = bathRoom.values.filter(item => item.checked).map(item => item.value)
    this.filterRefresh({
      'filterOptions.bathRoom': bathRoom,
      [`listParams.${bathRoom.keys}`]: query.length ? JSON.stringify(query) : ''
    })
  },
  selectTag: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      tag
    } = this.data.filterOptions
    if (tag.select === 1) {
      tag.values = tag.values.map((item, idx) => {
        item.checked = idx === index && !item.checked
        return item
      })
    } else {
      tag.values = tag.values.map((item, idx) => {
        if (idx === index) {
          item.checked = !item.checked
        }
        return item
      })
    }
    const query = tag.values.filter(item => item.checked).map(item => item.value)
    this.filterRefresh({
      'filterOptions.tag': tag,
      [`listParams.${tag.keys}`]: query.length ? JSON.stringify(query) : ''
    })
  },
  // 清空筛选
  resetFilterAction: function () {
    const {
      listParams,
      filterOptions
    } = this.data
    const {
      houseType,
      price,
      roomType,
      bedRoom,
      bathRoom,
      tag
    } = filterOptions

    if (houseType && listParams[houseType.keys]) {
      houseType.values = houseType.values.map(item => (item.checked = false, item))
    }
    if (price && listParams[price.keys]) {
      price.values = price.values.map(item => (item.checked = false, item))
    }
    if (roomType && listParams[roomType.keys]) {
      roomType.values = roomType.values.map(item => (item.checked = false, item))
    }
    if (bedRoom && listParams[bedRoom.keys]) {
      bedRoom.values = bedRoom.values.map(item => (item.checked = false, item))
    }
    if (bathRoom && listParams[bathRoom.keys]) {
      bathRoom.values = bathRoom.values.map(item => (item.checked = false, item))
    }
    if (tag && listParams[tag.keys]) {
      tag.values = tag.values.map(item => (item.checked = false, item))
    }
    this.filterRefresh({
      showBedBath: false,
      listParams: {
        contentType: listParams.contentType,
        schoolId: listParams.schoolId
      },
      filterOptions: {
        houseType: houseType || null,
        price: price || null,
        roomType: roomType || null,
        bedRoom: bedRoom || null,
        bathRoom: bathRoom || null,
        tag: tag || null
      }
    })
  },
  tapRoomTypeTip: function () {
    wx.navigateTo({
      url: '/pages/roomTypeIntro/roomTypeIntro'
    })
  },
  // 排序打开关闭
  tapSortAction: function (e) {
    this.setDataAction({
      sortSheetVisiable: !this.data.sortSheetVisiable
    })
  },
  // 排序选中，关闭
  selectSortAction: function (e) {
    const {
      index
    } = e.currentTarget.dataset
    const {
      sortOptions
    } = this.data
    sortOptions.values = sortOptions.values.map((item, idx) => {
      item.checked = idx === index // && !item.checked 禁止取消选择
      return item
    })
    const query = sortOptions.values.filter(item => item.checked).map(item => item.value)
    this.setData({
      sortOptions,
      'listQuery.page': 1,
      [`listParams.${sortOptions.keys}`]: query[0] || '',
      sortSheetVisiable: !this.data.sortSheetVisiable,
      bodyFixed: !this.data.bodyFixed
    })
    this.loadHouseList()
  },
  // 活动点击事件
  tapAdAction: function () {
    const {
      appUrl
    } = this.data.listAD.list[0]
    const {
      url
    } = urlParse(appUrl)
    wx.navigateTo({
      url: url
    })
  },
  // catch event noop
  tapCatchEvent: function () {}

})