// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_index_home
} = require('../../utils/api.js');

const app = getApp();
Page({
  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    selectedIndex: 0,
    isIPX: app.globalData.isIPX,
    homeData: null,
    citySelectObj: null,
    activityList: null,
    userInfo: null,
    isHideTop: true
  },

  onHide: function () {
    this.setData({
      isLoading: false
    })
  },


  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const {
      shareUid,
      shareCrmUid
    } = options;
    if (shareUid && shareUid.length) { // 分享用户id
      util.setStorageSync('shareUid', shareUid);
    }
    if (shareCrmUid && shareCrmUid.length) { // 分享管理端id
      util.setStorageSync('shareCrmUid', shareCrmUid);
    }

    // 为了兼容之前版本的城市id,现在叫cityId
    const citySelectObj = util.getStorageSync("citySelectObj");
    if (citySelectObj && citySelectObj.id) {
      citySelectObj.cityId = citySelectObj.id
      util.setStorageSync('citySelectObj');
    }
    this.loadHomeData();
    this.getUserInfo();
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const userInfo = util.getStorageSync('userInfo');
    let path = "/pages/index/index";
    if (userInfo && userInfo.userCode) { // 分享用户id
      path = path + `?shareUid=${userInfo.userCode}`
    }
    return {
      title: "hooli找房",
      path: path,
      imageUrl: "https://static.hoolihome.com/weapp/hoolihome/share.jpg"
    }
  },

  // 监听滚动条坐标
  onPageScroll: function (e) {
    let timer = null
    const _this = this
    timer && clearTimeout(timer)
    timer = setTimeout(() => {
      if (_this.data.isHideTop && e.scrollTop > 100) {
        _this.setData({
          isHideTop: false
        });
      } else if (e.scrollTop < 100 && !this.data.isHideTop) {
        _this.setData({
          isHideTop: true
        });
      }
    }, 300)
  },

  pageScrollTo: function () {
    wx.pageScrollTo({
      scrollTop: 0,
      duration: 100
    });
  },


  onPullDownRefresh: function () {
    if (this.data.selectedIndex == 0) {
      this.loadHomeData();
    } else {
      wx.stopPullDownRefresh();
    }
  },

  getUserInfo: function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo: userInfo
      })
    }
  },

  loadHomeData: function () {
    let params = {};
    params.url = api_index_home;
    params.data = {};
    net.req(params, true).then((data) => {
      // activity
      const activityObj = data.indexList.filter(item => item.cate == 7)[0]
      this.setData({
        isLoading: false,
        citySelectObj: data.cityList,
        homeData: data.indexList,
        activityList: activityObj.data || []
      });
      if (data.cityList) {
        util.setStorageSync('citySelectObj', data.cityList);
      }
      wx.stopPullDownRefresh();
    }, (e) => {
      this.setData({
        isLoading: false,
        homeData: null
      });
      wx.stopPullDownRefresh();
    });
  },

  tabTabbarAction: function (e) {
    let {
      id
    } = e.detail;
    this.setData({
      selectedIndex: id
    });

    if (!this.data.userInfo) {
      this.getUserInfo();
    }
  },
  refreshHomeData() {
    if (this.data.selectedIndex == 0) {
      this.loadHomeData();
    }
  }
})