// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_video_list,
  api_video_hit
} = require('../../utils/api.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    cityId: null,
    page: 1,
    pageSize: 8,
    videoList: null,
    canLoad: true
  },
  pageData: {
    scrollTop: 0
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.getWithData();
  },

  onPageScroll: function (e) {
    if (this.data.hidden) {
      this.pageData.scrollTop = e.scrollTop;
    }
  },

  onPullDownRefresh: function () {
    this.data.page = 1;
    this.data.videoList = [];
    this.setData({
      canLoad: true
    });
    this.loadData();

  },

  getWithData: function () {
    if (!this.data.cityId) {
      let citySelectObj = util.getStorageSync('citySelectObj');
      if (!citySelectObj) {
        wx.reLaunch({
          url: '/pages/citySelect/citySelect',
        });
        wx.stopPullDownRefresh();
        return false;
      } else {
        this.data.cityId = citySelectObj.id
      }
    }
    this.loadData();
  },

  loadData: function () {
    let params = {};
    params.url = api_video_list;
    params.data = {
      cityId: this.data.cityId,
      page: this.data.page,
      pageSize: this.data.pageSize
    };
    net.req(params, true).then((data) => {
      wx.stopPullDownRefresh();
      if (data.list && data.list.length < this.data.pageSize) {
        this.setData({
          canLoad: false
        })
      }
      let list = this.data.videoList || new Array();
      this.setData({
        isLoading: false,
        videoList: list.concat(data.list)
      });
    }, (e) => {
      wx.stopPullDownRefresh();
      this.setData({
        isLoading: false,
        homeData: null
      });
    });
  },

  tapVideoAction: function (e) {
    const {
      currentIndex
    } = e.currentTarget.dataset;
    const obj = this.data.videoList[currentIndex];
    this.hitVideoSee(obj.id);
    if (obj.id && obj.id.length) {
      wx.navigateTo({
        url: `/pages/video/video?id=${obj.id}`
      });
    }
  },

  hitVideoSee: function (videoId) {
    let params = {};
    params.url = api_video_hit;
    params.data = {
      id: videoId
    };
    net.req(params, true).then((data) => {}, (e) => {});
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.canLoad) {
      this.data.page = this.data.page + 1;
      this.loadData();
    }

  },


  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  }
})