// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_get_mobile_prefix,
  api_mobile_code,
  api_mobile_login
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');
const app = getApp();

Page({
  data: {
    isLoading: true,
    prefixArr: [],
    prefixIndex: 0,
    mobile: '',
    code: '',
    codeText: '获取验证码',
    btnCodeDisable: false,
    btnSureDisable: true,
    timer: null
  },
  onLoad: function (options) {
    this.loadPrefix();
  },
  onUnload: function () {
    let {
      timer
    } = this.data;
    if (timer) {
      clearTimeout(timer);
      timer = null;
    }
  },
  pickerChange: function (e) {
    this.setData({
      prefixIndex: e.detail.value
    });
  },
  mobileChange: function (e) {
    let mobile = e.detail.value;
    this.setData({
      mobile: mobile
    });
    let {
      code
    } = this.data;
    if (util.validator.checkMobile(mobile) && util.validator.checkCode(code)) {
      this.setData({
        btnSureDisable: false
      });
    } else {
      this.setData({
        btnSureDisable: true
      });
    }
  },
  codeChange: function (e) {
    let code = e.detail.value;
    this.setData({
      code: code
    });
    let {
      mobile
    } = this.data;
    if (util.validator.checkMobile(mobile) && util.validator.checkCode(code)) {
      this.setData({
        btnSureDisable: false
      });
    } else {
      this.setData({
        btnSureDisable: true
      });
    }
  },
  handleSendCode: function (e) {
    let {
      mobile,
      prefixArr,
      prefixIndex
    } = this.data;
    if (!util.validator.checkMobile(mobile)) {
      util.showToast('请输入正确的手机号码');
      return false;
    }
    let countryId = prefixArr[prefixIndex].id;
    this.sendSmsCode(countryId, mobile);
  },
  handleSure: function (e) {
    let {
      mobile,
      prefixArr,
      prefixIndex,
      code
    } = this.data;
    let countryId = prefixArr[prefixIndex].id;
    let params = {};
    params.url = api_mobile_login;
    params.data = {
      mobilePrefixId: countryId,
      mobile: mobile,
      verifyCode: code,
      loginType: 1,
      hooid: "hoolihome",
      oneEc: 'miniP',
      twoEc: 'miniP_rentals',
      oneSc: 'nature',
      twoSc: 'nature_search'
    };

    wx.showLoading({
      title: '努力登录中...',
    })
    const shareUid = util.getStorageSync('shareUid');
    if (shareUid && shareUid.length) { // 分享用户id
      params.data.shareUid = shareUid;
    }
    const shareCrmUid = util.getStorageSync('shareCrmUid');
    if (shareCrmUid && shareCrmUid.length) { // 分享管理端id
      params.data.shareCrmUid = shareCrmUid;
    }

    net.req(params, true).then((data) => {
      wx.hideLoading()
      if (data && data.userInfo && data.userInfo.token) {
        util.setStorageSync('userInfo', data.userInfo);
        let {
          loginSuccessNextUrl
        } = app.globalData;
        if (loginSuccessNextUrl && loginSuccessNextUrl.length) {
          app.globalData.loginSuccessNextUrl = '';
          loginSuccessNextUrl = decodeURIComponent(loginSuccessNextUrl);
          wx.reLaunch({
            url: loginSuccessNextUrl
          });
        } else {
          let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
          let prePage = pages[pages.length - 3]; /*我的页面对象*/
          if (prePage) {
            if (prePage.loginCallback) prePage.loginCallback();
            wx.navigateBack({
              delta: 2
            });
          } else {
            wx.navigateBack();
          }
        }
        return false;
      }
    }).catch(e => {
      wx.hideLoading()
      util.showToast(e.msg);
    });
  },
  loadPrefix: function () {
    let params = {};
    params.data = {
      range: 'B',
      prefix: '1'
    }
    params.url = api_get_mobile_prefix;
    net.req(params).then((res) => {
      if (res && Array.isArray(res) && res.length > 0) {
        let prefixArr = [];
        res.forEach((vvv, iii, aaa) => {
          let {
            list
          } = vvv;
          prefixArr = prefixArr.concat(list);
        });
        this.setData({
          isLoading: false,
          prefixArr: prefixArr
        }, () => {
          for (let i = 0; i < prefixArr.length; i++) {
            let tmp = prefixArr[i];
            if (["86", "086", "+86", "+086"].indexOf(tmp.code) !== -1) {
              this.setData({
                prefixIndex: i
              });
              break;
            }
          }
        });
      }
    });
  },
  sendSmsCode: function (countryId, mobile) {
    let params = {};
    params.url = api_mobile_code;
    params.data = {
      // countryId: countryId,
      mobilePrefixId: countryId,
      hooid: "hoolihome",
      mobile: mobile,
      senceId: 1,
      status: 5
    };
    net.req(params, true).then((res) => {
      this.countDown();
    }, (e) => {
      this.setData({
        btnCodeDisable: false
      });
      let tips = '发送验证码失败';
      if (e) {
        let {
          msg
        } = e;
        if (msg && 'fail' !== msg) {
          tips = msg;
        }
      }
      util.showToast(tips);
    });
    this.setData({
      btnCodeDisable: true
    });
  },
  countDown: function () {
    /*短信验证码倒计时*/
    let timeCount = 60;
    let loop = () => {
      if (timeCount > 0) {
        this.setData({
          codeText: `重新获取（${timeCount}s）`
        });
        timeCount--;
        this.data.timer = setTimeout(loop, 1000);
      } else {
        this.setData({
          codeText: `重新获取`,
          btnCodeDisable: false
        });
        if (this.data.timer) {
          clearTimeout(this.data.timer);
          this.data.timer = null;
        }
      }
    };
    loop();
  }
})