// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_get_mobile_prefix,
  api_apply_order
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');
const {
  mApi
} = require('../../utils/config.js');
Page({
  /**
   * 页面的初始数据
   */
  data: {
    prefixArr: [],
    prefixIndex: 0,
    cityData: [
      [],
      []
    ],
    allCityData: [],
    countryId: null,
    cityId: null,
    selectCityText: '',
    schoolName: '',
    schoolId: null,
    liveTime: '',
    firstName: '',
    firstNameW: true,
    lastName: '',
    lastNameW: true,
    mobilePrefixId: null,
    mobile: '',
    mobileW: true,
    wechatId: '',
    wechatIdW: true,
    email: '',
    extRemarks: '',
    canTap: true,
    isSelect: false
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.loadPrefix();
    this.getCityData();

    const userInfo = util.getStorageSync("userInfo");
    const user = {}
    if (userInfo.mobile) {
      user.mobile = userInfo.mobile
      user.mobileW = false
    }
    if (userInfo.email) {
      user.email = userInfo.email
    }
    this.setData(user)
    if (userInfo.mobilePrefixId) {
      this.data.mobilePrefixId = userInfo.mobilePrefixId
    }

    const date = new Date();
    const startDate = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate();
    const endDate = (date.getFullYear() + 3) + '-' + (date.getMonth() + 1) + '-' + date.getDate();
    this.setData({
      startDate: startDate,
      endDate: endDate
    })
  },

  loadPrefix: function () {
    let params = {};
    params.data = {
      range: 'B',
      prefix: '1'
    }
    params.url = api_get_mobile_prefix;
    net.req(params).then((res) => {
      if (res && Array.isArray(res) && res.length > 0) {
        let prefixArr = [];
        res.forEach((vvv, iii, aaa) => {
          let {
            list
          } = vvv;
          prefixArr = prefixArr.concat(list);
        });
        this.setData({
          isLoading: false,
          prefixArr: prefixArr
        }, () => {
          for (let i = 0; i < prefixArr.length; i++) {
            let tmp = prefixArr[i];
            if (this.data.mobilePrefixId) {
              if (this.data.mobilePrefixId == tmp.id) {
                this.setData({
                  prefixIndex: i
                });
                break;
              }
            } else {
              if (["86", "086", "+86", "+086"].indexOf(tmp.code) !== -1) {
                this.setData({
                  prefixIndex: i
                });
                break;
              }
            }
          }
        });
      }
    });
  },

  // 后两级第一个数据
  getCityData() {
    net.req({
      url: api_get_mobile_prefix,
      data: {
        range: 'B',
        level: JSON.stringify([1, 3])
      }
    }).then(data => {
      this.data.allCityData = data
      this.setData({
        'cityData[0]': data,
        'cityData[1]': data[0].son || [],
      })
    })
  },
  bindCityColumnChange(e) {
    const column = e.detail.column // 列index
    if (column == 0) {
      const value = e.detail.value
      const data = this.data.allCityData[value]
      this.setData({
        'cityData[0]': data,
        'cityData[1]': data.son || [],
      })
    }
  },
  bindCityChange(e) {
    const value = e.detail.value // 列index
    const data = this.data.allCityData[value[0]]
    const son = data.son[value[1]]
    this.data.countryId = data.id
    this.data.cityId = son.id
    this.setData({
      selectCityText: `${data.name}/${son.name}`
    })
  },

  // 入住日期
  timePickerChange: function (e) {
    this.setData({
      liveTime: e.detail.value
    })
  },

  tapSchoolAction: function () {
    const {
      selectCityText,
      countryId,
      cityId,
      schoolName
    } = this.data;
    if (selectCityText.length) {
      if (schoolName && schoolName.length) {
        wx.navigateTo({
          url: `/pages/searchSchool/searchSchool?countryId=${countryId}&cityId=${cityId}&schoolName=${schoolName}`
        });
      } else {
        wx.navigateTo({
          url: `/pages/searchSchool/searchSchool?countryId=${countryId}&cityId=${cityId}`
        });
      }
    } else {
      util.showModal({
        title: "提示",
        content: "请先选择意向城市",
        showCancel: false
      });
    }
  },

  bindinput: function (e) {
    let {
      currentTag,
      check
    } = e.currentTarget.dataset;
    const value = e.detail.value;
    if (util.validator.checkEmoji(value)) {
      util.showToast("输入内容含有特殊字符");
      this.setData({
        [`${currentTag}`]: value.replace(/\uD83C[\uDF00-\uDFFF]|\uD83D[\uDC00-\uDE4F]/g, "")
      })
    } else {
      this.data[currentTag] = value
      if (check) {
        const data = {}
        data[`${currentTag}W`] = !value.trim().length
        this.setData(data)
      }
    }

  },

  // 选择意向学校回调
  blockCallBack(res) {
    this.setData({
      schoolName: res.schoolName
    })
    if (res.schoolId) {
      this.data.schoolId = res.schoolId
    }
  },

  // 服务协议 勾选操作
  tapProtocolAction() {
    const {
      isSelect
    } = this.data
    this.setData({
      isSelect: !isSelect
    })
  },

  // 查看服务协议 /pages/hooli/service-agreement.html
  tapLookProtocol() {
    wx.navigateTo({
      url: '/pages/webView/webView?webUrl=' + encodeURIComponent(`${(mApi())}/pages/hooli/service-agreement.html`)
    });
  },

  // 立即预约
  sureBtnAction: function () {
    if (this.judgeWithParams() && this.data.canTap) {
      const {
        countryId,
        cityId,
        mobile,
        schoolName,
        schoolId,
        firstName,
        lastName,
        email,
        wechatId,
        liveTime,
        prefixIndex,
        prefixArr,
        extRemarks
      } = this.data;
      util.showLoading({
        title: "努力提交中..."
      });
      this.data.canTap = false; // 不能连续点击
      const tmp = prefixArr[prefixIndex];
      let params = {};
      params.url = api_apply_order;
      params.data = {
        countryId: countryId,
        cityId: cityId,
        firstName: firstName,
        lastName: lastName,
        mobilePrefix: tmp.code,
        mobile: mobile,
        wechatId: wechatId,
        mobileCountryId: tmp.id,
        schoolName: schoolName,
        oneEc: 'miniP',
        twoEc: 'miniP_rentals',
        oneSc: 'nature',
        twoSc: 'nature_search'
      };

      if (liveTime && liveTime.length) {
        params.data.liveTime = liveTime;
      }
      if (schoolId) {
        params.data.schoolId = schoolId;
      }
      if (extRemarks && extRemarks.length) {
        params.data.extRemarks = extRemarks;
      }
      if (email && email.length) {
        params.data.email = email;
      }

      const shareUid = util.getStorageSync('shareUid');
      if (shareUid && shareUid.length) { // 分享用户id
        params.data.shareUid = shareUid;
      }
      const shareCrmUid = util.getStorageSync('shareCrmUid');
      if (shareCrmUid && shareCrmUid.length) { // 分享管理端id
        params.data.shareCrmUid = shareCrmUid;
      }

      net.req(params, true).then((data) => {
        util.hideLoading();
        wx.navigateTo({
          url: '/pages/applySucceed/applySucceed'
        });
        this.data.canTap = true;
      }, (e) => {
        this.data.canTap = true;
        util.hideLoading();
        util.showToast(e.msg);
      });
    }
  },


  judgeWithParams: function () {
    const {
      selectCityText,
      schoolName,
      firstName,
      lastName,
      mobile,
      wechatId,
      email,
      isSelect
    } = this.data;

    if (!selectCityText.length) {
      util.showToast("请选择意向城市");
      return false;
    }
    if (!schoolName.length) {
      util.showToast("请选择意向学校");
      return false;
    }
    if (!util.validator.checkMobile(mobile)) {
      util.showToast("请输入正确手机号");
      return false;
    }

    if (!firstName.length) {
      util.showToast("请输入您的姓");
      return false;
    }

    if (!lastName.length) {
      util.showToast("请输入您的名");
      return false;
    }

    if (wechatId.length < 4) {
      util.showToast("请正确输入您的微信号，以便我们与您联系");
      return false;
    }

    if (email.length > 0 && !util.validator.checkEmail(email)) {
      util.showToast("请输入正确邮箱地址");
      return false;
    }

    if (!isSelect) {
      util.showToast("请阅读并同意《服务协议》");
      return false;
    }

    return true;
  }
})