// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_search_house
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');

Page({

  /**
   * 页面的初始数据
   */
  data: {
    dataArr: [],
    historyArr: [],
    inputValue: ''
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const historyArr = util.getStorageSync("SEARCHHISTORY");
    if (historyArr && historyArr.length) {
      this.setData({
        historyArr: JSON.parse(decodeURIComponent(historyArr))
      })
    }
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {

  },

  bindSearch: function (e) {
    const { value } = e.detail;
    this.setData({
      inputValue: value
    })
    if (value && value.trim().length) {
      let params = {};
      params.url = api_search_house;
      params.data = {
        key: value.trim(),
        program: "miniv2",
        type: "[1,2,3,5]" // 1：城市、2：学校、3：房源-楼、5社会房源
      };
      net.req(params, true).then((data) => {
        // this.dealWithData(data)
        if (Array.isArray(data)) {
          this.setData({
            dataArr: data
          });
        } else {
          this.setData({
            dataArr: []
          });
        }
      }, (e) => {
        this.setData({
          dataArr: []
        });
      });
    } else {
      this.setData({
        dataArr: [],
        inputValue: ''
      })
    }
  },


  dealWithData: function (arr) {
    if (!arr || !Array.isArray(arr) || arr.length === 0) {
      return false
    }
    const s = `<b style="color:#FF523D;font-size:18px">${this.data.inputValue}</b>`;
    const reg = new RegExp(this.data.inputValue, 'gi')
    arr.forEach((val, i) => {
      let {
        name
      } = val;
      if (name) {
        val.sname = name.replace(reg, s)
      }
    })
    this.setData({
      dataArr: arr
    });
  },

  tapItemAction: function (e) {
    const {
      item
    } = e.currentTarget.dataset;
    // 在内存中的所有页面栈对象
    const pages = getCurrentPages();
    // 1：城市、2：学校、3：房源-楼、5社会房源
    // if (item.type == 1) {
    let cityObj = util.getStorageSync("citySelectObj")

    if (parseInt(item.type) == 2 && cityObj.schoolId != item.id) {
      cityObj = {
        schoolId: item.id,
        cityId: item.cityId
      }
      util.setStorageSync("citySelectObj", cityObj)
      // 刷新首页数据
      let launchPage = pages[0]
      if (launchPage && launchPage.refreshHomeData) {
        launchPage.refreshHomeData()
      }
    } else {
      if (cityObj.cityId !== item.cityId) {
        cityObj = {
          cityId: item.cityId,
        }
        util.setStorageSync("citySelectObj", cityObj)
        // 刷新首页数据
        let launchPage = pages[0]
        if (launchPage && launchPage.refreshHomeData) {
          launchPage.refreshHomeData()
        }
      }
    }

    // }
    if (item.type == 3) {
      wx.navigateTo({
        url: `/pages/houseDetail/houseDetail?code=${item.code}`
      })
    } else if (item.type == 5) {
      wx.navigateTo({
        url: `/pages/roomDetail/roomDetail?code=${item.code}`
      })
    } else {
      let prePage = pages[pages.length - 2]; /*列表页面对象*/

      if (prePage && prePage.route == "pages/houseList/houseList") {
        if (prePage.updateDataCallback) {
          prePage.updateDataCallback(item)
        }
        wx.navigateBack();
      } else {
        let path = `/pages/houseList/houseList?searchValue=${encodeURIComponent(JSON.stringify(item))}&form=search`;
        wx.navigateTo({
          url: path
        })
      }
    }
    this.updateHistory(item);
  },

  updateHistory: function (item) {
    if (!item) return

    const historyArr = this.data.historyArr || [];
    // 删除旧记录，添加到前面
    const oldIndex = historyArr.findIndex(it => (it.type === item.type) && (it.id === item.id))
    if (oldIndex !== -1) {
      historyArr.splice(oldIndex, 1)
    }
    // 超出30删除最后一条记录
    if (historyArr.length === 10) {
      historyArr.pop();
    }
    const newHis = [item].concat(historyArr)

    this.setData({
      historyArr: newHis
    });
    util.setStorageSync("SEARCHHISTORY", encodeURIComponent(JSON.stringify(newHis)));
  },

  clearAllAction: function () {
    this.setData({
      dataArr: [],
      inputValue: ''
    })
  },

  clearHitoryAction: function () {
    util.removeStorageSync("SEARCHHISTORY");
    this.setData({
      historyArr: []
    })
  },

  tapCancelAction: function () {
    wx.navigateBack()
  }

})