const util = {
  getLoginUserInfo: () => { //获取用户登录信息,可判断是否登录
    let loginUserInfo = wx.getStorageSync('userInfo');
    if (!loginUserInfo) {
      loginUserInfo = wx.getStorageSync('userInfo');
    }
    return loginUserInfo;
  },
  getStorageSync: (key) => {
    /*由于wx.getStorageSync有一定概率取不到值，若取不到再取一次*/
    try {
      let value = wx.getStorageSync(key);
      if (!value) {
        value = wx.getStorageSync(key);
      }
      return value;
    } catch (e) {
      return null;
    }

  },
  setStorageSync: (key, obj) => {
    /*wx.setStorageSync*/
    if (key && obj) {
      try {
        wx.setStorageSync(key, obj);
      } catch (e) {
        // Do something when catch error
      }
    }
  },
  removeStorageSync: (key) => {
    /*wx.removeStorageSync*/
    if (key) {
      try {
        wx.removeStorageSync(key);
      } catch (e) {
        // Do something when catch error
      }
    }
  },
  clearStorageSync: () => {
    /*wx.clearStorageSync*/
    try {
      wx.clearStorageSync();
    } catch (e) {
      // Do something when catch error
    }
  },
  showToast: (title, icon, mask, duration) => {
    /*wx.showToast*/
    try {
      wx.showToast({
        title: title || "",
        icon: icon || 'none',
        duration: duration || 3000,
        mask: mask || false,
      });
    } catch (e) {
      // Do something when catch error
    }
  },
  showModal: (obj) => {
    if (!obj) return;
    try {
      wx.showModal({
        title: obj.title || "",
        content: obj.content || "",
        showCancel: obj.showCancel == null ? true : false,
        confirmText: obj.confirmText || "确定",
        success: function (res) {
          if (res.confirm) {
            if (obj.success) obj.success(res);
          }
        }
      });
    } catch (e) {
      // Do something when catch error
    }

  },

  showLoading: (obj) => {
    if (!obj) return;
    try {
      wx.showLoading({
        title: obj.title || "",
        content: obj.mask == null ? false : obj.mask,
        success: function (res) {
          if (res.confirm) {
            if (obj.success) obj.success(res);
          }
        },
        fail: function (res) {
          if (obj.fail) obj.fail(res);
        },
        complete: function (res) {
          if (obj.complete) obj.complete(res);
        }
      });
    } catch (e) {
      // Do something when catch error
    }
  },

  hideLoading: (obj) => {
    if (!obj) {
      try {
        wx.hideLoading();
      } catch (e) {
        // Do something when catch error
      }
    } else {
      try {
        wx.hideLoading({
          success: function (res) {
            if (res.confirm) {
              if (obj.success) obj.success(res);
            }
          },
          fail: function (res) {
            if (obj.fail) obj.fail(res);
          },
          complete: function (res) {
            if (obj.fail) obj.complete(res);
          }
        });
      } catch (e) {
        // Do something when catch error
      }
    }

  },
  promisify: (api) => {
    /*wx api使用转成Promise形式*/
    return (options, ...params) => {
      return new Promise((resolve, reject) => {
        const extras = {
          success: resolve,
          fail: reject
        }
        api({
          ...options,
          ...extras
        }, ...params)
      })
    }
  },
  filterEmoji: (s) => {
    /*过滤表情*/
    if (s) {
      return s.replace(/\uD83C[\uDF00-\uDFFF]|\uD83D[\uDC00-\uDE4F]/g, '');
    }
    return '';
  },
  validator: {
    /*校验字段合法性rule*/
    checkMobile: (s) => {
      /*校验手机号格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^\d{3,20}$/;
        return rule.test(s);
      }
      return false;
    },
    checkEmail: (s) => {
      /*校验邮箱格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^(([^()[\]\\.,;:\s@\"]+(\.[^()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/g
        return rule.test(s);
      }
      return false;
    },
    checkPwd: (s) => {
      /*校验登录密码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^(?=.*[a-zA-Z]+)(?=.*[0-9]+)[a-zA-Z0-9]{8,16}$/;
        return rule.test(s);
      }
      return false;
    },
    checkCode: (s) => {
      /*校验短信或邮箱验证码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^\d{6}$/;
        return rule.test(s);
      }
      return false;
    },
    checkImgCode: (s) => {
      /*校验图片验证码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^[a-zA-Z]{4}$/;
        return rule.test(s);
      }
      return false;
    },
    checkNickname: (s) => {
      /*校验昵称格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^[A-Za-z0-9\u4e00-\u9fa5]{2,20}$/;
        return rule.test(s);
      }
      return false;
    },
    checkEmoji: (s) => {
      /*校验是否含有emoji表情*/
      if (s) {
        s = s.toString().trim();
        var rule = /\uD83C[\uDF00-\uDFFF]|\uD83D[\uDC00-\uDE4F]/g;
        return rule.test(s);
      }
      return false;
    },
  },
  isExist: (obj) => {
    if (null === obj || obj === undefined || obj === "undefined" || "null" === obj) {
      return false;
    }
    return true;
  },
  jsonClone: obj => {
    try {
      return JSON.parse(JSON.stringify(obj))
    } catch (e) {
      return obj
    }
  },
  deepClone: (obj) => {
    /*深度克隆对象*/
    if (null === obj || 'object' !== typeof obj) {
      return obj;
    }
    let clone;
    if (obj instanceof Date) {
      clone = new Date();
      clone.setTime(obj.getTime());
      return clone;
    }
    if (obj instanceof Array) {
      clone = [];
      let i, n = obj.length;
      for (i = 0; i < n; i++) {
        clone[i] = util.deepClone(obj[i]);
      }
      return clone;
    }
    if (obj instanceof Object) {
      clone = {};
      for (let key in obj) {
        if (obj.hasOwnProperty(key)) {
          clone[key] = util.deepClone(obj[key]);
        }
      }
      return clone;
    }
    throw new Error(`Unable to clone obj! Its type isn't supported.`);
  },
  arrayRemove: (val, arr) => {
    /*删除数组内某个元素*/
    if (!arr || !Array.isArray(arr)) {
      return;
    }
    arr.forEach((v, i, a) => {
      if (val === v) {
        a.splice(i, 1);
      }
    });
  },
  cstr: (s) => {
    /*处理null、undefined或NaN字符串*/
    if (s) {
      return s.toString();
    } else {
      return '';
    }
  },
  formatTimeCount: (t) => {
    /*格式化时间戳差*/
    if (t > 0) {
      let h = Math.floor(t / 60 / 60 % 24);
      if (h < 10) {
        h = `0${h}`;
      }
      let m = Math.floor(t / 60 % 60);
      if (m < 10) {
        m = `0${m}`;
      }
      let s = Math.floor(t % 60);
      if (s < 10) {
        s = `0${s}`;
      }
      return `${h}:${m}:${s}`;
    }
    return '';
  },
  formatTimeStr: (t) => {
    if (t) {
      t = parseInt(t);
      let time = new Date(t * 1000);
      let year = time.getFullYear();
      let month = time.getMonth() + 1;
      if (month < 10) {
        month = `0${month}`;
      }
      let date = time.getDate();
      if (date < 10) {
        date = `0${date}`;
      }
      let hour = time.getHours();
      if (hour < 10) {
        hour = `0${hour}`;
      }
      let minute = time.getMinutes();
      if (minute < 10) {
        minute = `0${minute}`;
      }
      let second = time.getSeconds();
      if (second < 10) {
        second = `0${second}`;
      }
      return `${year}-${month}-${date} ${hour}:${minute}:${second}`;
    }
    return '';
  },
  money: (m, c, w) => {
    /*m:金额;c:保留小数位数,只能取值0,1,2;w:1返回整个金额,2返回整数部分,3返回小数部分*/
    if (c !== 0 && c !== 1 && c !== 2) {
      console.log('传入保留小数位数参数错误');
      return '';
    }
    if (w !== 1 && w !== 2 && w !== 3) {
      console.log('传入返回类型参数错误');
      return '';
    }

    if (0 === m) {
      /*由于0=false,需特殊处理*/
      return deal('0', '');
    } else {
      if (!m || isNaN(m)) {
        return '';
      }
      m = m.toString();
      if (-1 === m.indexOf('.')) {
        return deal(m, '');
      } else {
        var s_arr = m.split('.');
        return deal(s_arr[0], s_arr[1]);
      }
    }

    function deal(p, f) {
      /*p为整数部分*/
      if (0 === c) {
        if (1 === w) {
          return p;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return '';
        }
      } else if (1 === c) {
        if (0 === f.length) {
          f = '0';
        } else if (f.length >= 2) {
          f = f.substring(0, 1);
        }
        if (1 === w) {
          return p + '.' + f;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return f;
        }
      } else if (2 === c) {
        if (0 === f.length) {
          f = '00';
        } else if (1 === f.length) {
          f = f + '0';
        } else if (f.length >= 3) {
          f = f.substring(0, 2);
        }
        if (1 === w) {
          return p + '.' + f;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return f;
        }
      }
    }
  },
  // ahex 转 rgba
  colorToRgba(color) {
    let rgba = "";
    color = color.substr(1);
    let colorLen = color.length;
    let aValue, rValue, gValue, bValue;
    aValue = "0xFF";
    if (colorLen === 6 || colorLen === 8) {
      if (colorLen === 8) {
        aValue = "0x" + color.substr(0, 2);
        color = color.substr(2);
      }
      rValue = "0x" + color.substr(0, 2);
      gValue = "0x" + color.substr(2, 2);
      bValue = "0x" + color.substr(4, 2);

      let alpha = parseInt(aValue) / 255.0;
      if (JSON.stringify(alpha).length > 4) { //小数点超过三位，四舍五入小数点后两位
        alpha = alpha.toFixed(2);
      }
      rgba = "rgba(" + parseInt(rValue) + "," + parseInt(gValue) + "," + parseInt(bValue) + "," + alpha + ")";
    }
    return rgba;
  },

  /**
   * 版本号比较
   * https://developers.weixin.qq.com/miniprogram/dev/framework/compatibility.html
   */
  compareVersion: function (v1, v2) {
    v1 = v1.split(".");
    v2 = v2.split(".");
    const len = Math.max(v1.length, v2.length);

    while (v1.length < len) {
      v1.push("0");
    }
    while (v2.length < len) {
      v2.push("0");
    }

    for (let i = 0; i < len; i++) {
      const num1 = parseInt(v1[i]);
      const num2 = parseInt(v2[i]);

      if (num1 > num2) {
        return 1;
      } else if (num1 < num2) {
        return -1;
      }
    }

    return 0;
  },

  isUndef: val => {
    return val === undefined || val === null
  },
  // appUrl解析成对象，{ query, url }
  urlParse: function (url) {
    // h5链接
    if (url.indexOf('http') === 0) {
      return {
        query: {},
        url: '/pages/webView/webView?webUrl=' + encodeURIComponent(url)
      }
    }
    // 其它格式
    return util.jumpUrlParse(url)
  },

  jumpUrlParse(urlQuery) {
    const query = util.getUrlQuery(urlQuery);
    let url = ''
    // 2	楼详情页 3	散房详情页 4	楼-商品详情页 7	海外攻略 -视频 9	h5页面 20	预约顾问 30 跳转小程序(无需处理)
    // 32 邀请活动页
    switch (parseInt(query.model)) {
      case 2:
        url = `/pages/houseDetail/houseDetail?code=${query.code}`
        break
      case 4:
      case 3:
        url = `/pages/roomDetail/roomDetail?code=${query.code}`
        break
      case 9:
        url = `/pages/webView/webView?webUrl=${query.url}`
        break
      case 20:
        url = `/pages/reserveAdviser/reserveAdviser`
        break
      case 32:
        url = `/pages/inviteFriends/inviteFriends`
        break
      default:
        break
    }
    return {
      query,
      url
    }
  },

  getUrlQuery(url) {
    const result = {}
    if (typeof url !== 'string') return result

    const query = url.split('?')[1]
    if (!query) return result

    query.split('&').forEach(value => {
      const v = value.split('=')
      result[v[0]] = v[1]
    })
    return result
  },

  /**
   * 函数防抖(只执行最后一次点击)
   */
  debounce: (fn, delay) => {
    let timer = null;
    delay = delay || 300;
    return (...args) => {
      clearTimeout(timer);
      timer = setTimeout(() => {
        fn.apply(this, args);
      }, delay);
    };
  },
  /**
   * 函数节流
   */
  throttle: (fn, delay) => {
    let last = Date.now();
    delay = delay || 300;
    return (...args) => {
      let now = Date.now();
      if (now - last >= delay) {
        last = now;
        fn.apply(this, args);
      }
    };
  }
};
module.exports = util;